# encrypticoin_ssi

## 0.3.2
- Fix PyPI packaging issues

## 0.3.1
- Update package metadata

## 0.3.0
- Exclude testing files from sdist

## 0.2.5
- Change the message id-extraction implementation

## 0.2.4
- Add proxy support for the requests

## 0.2.3
- Provide url_base construction client API

## 0.2.2
- Allow further customization during setup

## 0.2.1
- Update contract-info API docstring and test (decimals added)

## 0.2.0
- Add contract-info API call

## 0.1.2
- Better setup procedure support for ServerIntegrationClient

## 0.1.1
- Initial release
